@@ -11,7 +11,7 @@ use warnings;
 use Carp;
 use Rex::Helper::Run;
 
-our $VERSION = '1.12.2.1'; # TRIAL VERSION
+our $VERSION = '1.12.2.2'; # TRIAL VERSION
 
 sub new {
   my $that  = shift;
@@ -77,7 +77,7 @@ sub can_run {
     return $output[0];
   }
 
-  return undef; ## no critic ProhibitExplicitReturnUndef
+  return undef;
 }
 
 sub direct_exec {
