@@ -9,7 +9,7 @@ package Rex::Interface::Fs::HTTP;
 use strict;
 use warnings;
 
-our $VERSION = '1.12.2.1'; # TRIAL VERSION
+our $VERSION = '1.12.2.2'; # TRIAL VERSION
 
 use Rex::Commands;
 use Rex::Interface::Exec;
@@ -78,7 +78,7 @@ sub stat {
     return %{ $resp->{stat} };
   }
 
-  return undef; ## no critic ProhibitExplicitReturnUndef
+  return undef;
 }
 
 sub is_readable {
