@@ -9,7 +9,7 @@ package Rex::Interface::Fs::Sudo;
 use strict;
 use warnings;
 
-our $VERSION = '1.12.2.1'; # TRIAL VERSION
+our $VERSION = '1.12.2.2'; # TRIAL VERSION
 
 require Rex::Commands;
 use Rex::Interface::Fs::Base;
@@ -104,7 +104,7 @@ sub is_dir {
   $self->_exec("test -d $path");
   my $ret = $?;
 
-  $ret == 0 ? return 1 : return undef; ## no critic ProhibitExplicitReturnUndef
+  $ret == 0 ? return 1 : return undef;
 }
 
 sub is_file {
@@ -118,7 +118,7 @@ sub is_file {
   $self->_exec("test -d $file");
   my $is_dir = $?;
 
-  ( $is_file == 0 && $is_dir != 0 ) ? return 1 : return undef; ## no critic ProhibitExplicitReturnUndef
+  ( $is_file == 0 && $is_dir != 0 ) ? return 1 : return undef;
 }
 
 sub unlink {
@@ -172,7 +172,7 @@ sub stat {
   );
 
   if ( !$out ) {
-    return undef; ## no critic ProhibitExplicitReturnUndef
+    return undef;
   }
 
   my $tmp = decode_json($out);
